; Emacs support for LAML midi processing.
; Load this file in your emacs init file:  .emacs

(provide 'laml-chords-support)

; ---------------------------------------------------------------------------------------------------------------
; Midi Laml Mode stuff and key/menu bidings.
; The mode is backed up by the file extension "midl".

(define-derived-mode 
	midi-laml-mode laml-mode "MidiLaml" 
  "The MidiLaml mode is a specialization of Laml mode which supports programmed MIDI solutions
in a particular MIDI XML-in-LAML language.
The LAML MIDI processor is a part of the LAML distribution.
LAML means 'Lisp Abstracted Markup Language'. LAML makes HTML and XML languages available as 
Scheme functions."

  (if (> (size-of-current-buffer) 250000)
      (font-lock-mode -1)
      (font-lock-mode  1))

)

(defun size-of-current-buffer ()
   (point-max))

; Midi LAML keymap:
(defvar midi-laml-mode-map (make-sparse-keymap "MidiLaml"))

(laml-define-key midi-laml-mode-map [menu-bar midi-laml]
    (cons "Midi Laml" (make-sparse-keymap "MidiLaml")))

(laml-define-key midi-laml-mode-map "\C-i" 'goto-next-input-field)

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml format-attributes-of-multi-pad]
      '("Format attributes of multipad form" . format-attributes-of-multi-pad))

(laml-define-key midi-laml-mode-map [menu-bar midi-laml menu-midi-laml-sep-3]
    '("----"))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml outdent-channel]
      '("Outdent channel of track..." . outdent-channel))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml outdent-multiple-channels]
      '("Outdent multiple channels of track..." . outdent-multiple-channels))

(laml-define-key midi-laml-mode-map [menu-bar midi-laml menu-midi-laml-sep-2]
    '("----"))

(laml-define-key midi-laml-mode-map [menu-bar midi-laml set-c]
    (cons "Set lower C" (make-sparse-keymap "Set lower C for score comments")))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml report-lower-c]
      '("What is lower C" . report-lower-c))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c7]
      '("Set lower C to C7 (96)" . (lambda () (interactive) (set-c-value 96))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c6]
      '("Set lower C to C6 (84)" . (lambda () (interactive) (set-c-value 84))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c5]
      '("Set lower C to C5 (72)" . (lambda () (interactive) (set-c-value 72))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c4]
      '("Set lower C to C4 (60)" . (lambda () (interactive) (set-c-value 60))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c3]
      '("Set lower C to C3 (48)" . (lambda () (interactive) (set-c-value 48))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c2]
      '("Set lower C to C2 (36)" . (lambda () (interactive) (set-c-value 36))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c1]
      '("Set lower C to C1 (24)" . (lambda () (interactive) (set-c-value 24))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml set-c set-c-to-c0]
      '("Set lower C to C0 (12)" . (lambda () (interactive) (set-c-value 12))))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml remove-score-comments-of-region]
      '("Remove score comments of region" . remove-score-comments-of-region))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml add-score-comments-of-form-channel]
      '("Add score comments to channel of form..." . add-score-comments-of-form-channel))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml remove-score-comments-of-form]
      '("Remove score comments from form" . remove-score-comments-of-form))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml add-score-comments-of-region]
      '("Add score comments to region" . add-score-comments-of-region))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml add-score-comments-of-form]
      '("Add score comments to form" . add-score-comments-of-form))

(laml-define-key midi-laml-mode-map [menu-bar midi-laml menu-midi-laml-sep-1]
    '("----"))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml pop-and-reestablish-midl-file]
      '("Pop and reestablish source" . pop-and-reestablish-midl-file))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml process-laml-file-save-and-push]
      '("Process, save and push source" . process-laml-file-save-and-push))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml process-laml-file-and-save]
      '("Process and Save ..." . process-laml-file-and-save))

(laml-define-key  midi-laml-mode-map [menu-bar midi-laml process-laml-file-and-play]
      '("Process and Play" . process-laml-file-and-play))

(laml-define-key midi-laml-mode-map (list "\C-o" "\C-c\C-o") 'process-laml-file-and-play)

(laml-define-key midi-laml-mode-map (list "\C-c\C-s" "\C-c\C-s") 'process-laml-file-and-save)

(setq auto-mode-alist 
      (cons '("\\.midl" . midi-laml-mode)
	    auto-mode-alist))



; ---------------------------------------------------------------------------------------------------------------


(defun midi-to-laml (processing-mode counter-transposition) 
  "From dired, process the selected midi file to the corresponding LAML file. Create a midi-temp directory for
temporary files."
 (interactive (list 
                (completing-read "Processing mode: " '(("absTime" . nil) ("absTime-on-off" . nil) ("deltaTime" . nil) ("raw" . nil)) nil nil "absTime")
                (completing-read "Counter transposition: " '() nil nil "0")))
 
 ; Ensure that the midi-temp directory exists
 (if (not (file-exists-p (concat (current-directory) "midi-temp/")))   ; directory existence
     (make-directory (concat (current-directory) "midi-temp/")))
 
 (let ((selected-files (dired-get-marked-files nil)))
   (if (and (= 1 (length selected-files)) (file-regular-p (car selected-files)))
       (let* ((full-path-midi-file (car selected-files))
              (ext (file-name-extension full-path-midi-file)))
         (if (midi-extension-p ext)
             (let ((track-separation (ask-user "Should the midi file be track separated [yes/no]?" "no")))
               (midi-file-to-laml-file processing-mode counter-transposition track-separation full-path-midi-file))
             (midi-file-to-laml-file processing-mode counter-transposition nil full-path-midi-file))
         (other-window 1)
       )
     (progn
       (beep)
       (message "Cannot process. You should only select a single midi file.")))))

(defun midi-extension-p (x)
  (or (equal (downcase x) "mid") (equal (downcase x) "midi")))

; Asynchronous midi file to laml file processing via laml temp dir.
(defun midi-file-to-laml-file (processing-mode counter-transposition track-separation full-path-midi-file) 
  (let ((laml-temp-processing-dir (concat laml-dir "temp/"))) 
    (make-a-file-from-laml-template 
       "temp-processing-program.laml"
       laml-temp-processing-dir
       "midi-to-laml-processor"
       'laml-mode
       (list
        (list "FULL-PATH-TO-MIDI-FILE" full-path-midi-file)
        (list "THE-PROCESSING-MODE" processing-mode)
        (list "THE-COUNTER-TRANSPOSITION" counter-transposition)
        (list "THE-TRACK-SEPARATION" (if track-separation "true" "false"))
        )
       (concat laml-dir "styles/xml-in-laml/midi/" "templates/"))  
    (laml-process-file  (concat laml-temp-processing-dir "temp-processing-program.laml"))))

; Synchronous version with more parameters
(defun sync-midi-file-to-laml-file (processing-mode counter-transposition track-separation full-path-midi-file full-path-laml-file) 
  (let ((laml-temp-processing-dir (concat laml-dir "temp/"))) 
    (make-a-file-from-laml-template 
       "temp-processing-program.laml"
       laml-temp-processing-dir
       "sync-midi-to-laml-processor"
       'laml-mode
       (list
        (list "FULL-PATH-TO-MIDI-FILE" full-path-midi-file)
        (list "FULL-PATH-TO-LAML-FILE" full-path-laml-file)
        (list "THE-PROCESSING-MODE" processing-mode)
        (list "THE-COUNTER-TRANSPOSITION" counter-transposition)
        (list "THE-TRACK-SEPARATION" (if track-separation "true" "false"))
        )
       (concat laml-dir "styles/xml-in-laml/midi/" "templates/"))  
    (laml-sync-process-file (concat laml-temp-processing-dir "temp-processing-program.laml") 'silent)))


; The function midi-to-laml is bound to a dired menu entry in the function laml-enable-dired-mode of
; the file emacs-support/laml-key-menu-bindings.el.
; The file laml-key-menu-bindings.el is part of the LAML distribution.

; ---------------------------------------------------------------------------------------------------------------

(defun outdent-channel (n)
 "Outdent all midi messages that belong to channel n"
 (interactive "nOutdent channel: ")
 (message (concat "Outdenting channel " (number-to-string n) "..."))
 (save-excursion
  (if (not (looking-at "(MidiTrack"))
      (backward-up-list 1))
  (let ((limit (point))
        (done nil))
    (forward-sexp 1) (backward-char 1)
    
    (while (not done)
      (if (re-search-backward 
           (regular-expression 
            `(concat "'channel" (one-or-more " ") (concat "\"") ,(int-to-string n) (concat "\"")))
           limit t)
          (progn
            (beginning-of-line 1)
            (indent-amount -2)
          )
          (setq done t)))))
  (message "DONE"))

(defun outdent-multiple-channels (str-int-lst)
  (interactive "sOutent which channels (numbers separated by space): ")
  (message (concat "Outdenting channels " str-int-lst "..."))
  (save-excursion
    (let ((n-list (car (read-from-string (concat "(" str-int-lst ")")))))
      (mapcar (function outdent-channel) n-list)))
  (message "DONE"))
    


(defun indent-amount (a)
  (if (> a 0)
      (insert (make-string a 32))
      (let ((count 0))
        (while (and (< count (abs a)) (looking-at " "))
           (delete-char 1)
           (setq count (+ count 1))))))



; ---------------------------------------------------------------------------------------------------------------

(defun format-attributes-of-multi-pad ()
  "Reformat the attributes of a TyrosMulitiPad form."
  (interactive)

  (save-excursion
    (beginning-of-buffer) (search-forward "'name-1") (beginning-of-line 1)

    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)
    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line)
    (forward-char 1)

    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)
    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line)
    (forward-char 1)

    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)
    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line)
    (forward-char 1)

    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)
    (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line 1) (delete-char 1)   (end-of-line)
    (forward-char 1)))

; ---------------------------------------------------------------------------------------------------------------
; OVERLAY STUFF

(defvar overlayable-forms nil)

(setq overlayable-forms
  (regular-expression
    '(concat "(" (one-or-more " ")
       (or "ProgramChange" "ControlChange" "NoteOn" "NoteOff" "SysEx" "Meta")   ; more
    )))

(defun prepare-overlaying ()
 (interactive)
 (remove-overlays-from-current-buffer)
 (setq buffer-invisibility-spec nil)
 (let ((count 0))
 (save-excursion
  (goto-char (point-min))
  (let ((done nil))
    (while (not done)
      (if (re-search-forward overlayable-forms nil t)
        (let* ((kind (type-of-overlay-under (point)))
               (ext (extension-of-overlay-under (point)))
               (overlay (make-overlay (car ext) (cdr ext) (current-buffer))))
          (overlay-put overlay 'invisible kind)
          (overlay-put overlay 'intangible nil)   ; ???
          (setq count (+ count 1))
          (message (number-to-string count))
        )
        (setq done t)))))))

(defun remove-overlays-from-current-buffer()
  (let ((overlay-list (overlays-in (point-min) (point-max))))
    (mapcar (function (lambda (o) (delete-overlay o))) overlay-list)))

; Return the type of the overlay of the form under point. 
; Point is assumed to be inside the form (a XML-in-LAML midi message).
(defun type-of-overlay-under (p)
  (save-excursion 
    (backward-up-list 1)
    (forward-char)
    (let ((name-of-form (string-to-symbol (prog-name-under-point))))
      (backward-up-list 1)
      (let ((p0 (point)))
        (forward-sexp 1)
        (let ((p1 (point)))
          (backward-sexp 1)
          (let ((channel-p (search-forward "'channel" p1 t)))
            (if channel-p
                (int-value-of-string-ahead)
              name-of-form)))))))

(defun int-value-of-string-ahead ()
  (progn
    (search-forward "\"")
    (let ((p2 (point)))
      (search-forward "\"")
      (string-to-int (buffer-substring p2 (- (point) 1))))))

; Return a cons pair of start and end position of the overlay of the form under point. 
; Point is assumed to be inside the form (a XML-in-LAML midi message).
(defun extension-of-overlay-under (p)
  (save-excursion 
    (backward-up-list 1)
    (let ((p0 (point)))
      (forward-sexp 1)
      (end-of-line 1) 
      (while (looking-at-chars (point) white-space-char-list) (forward-char 1))
      (cons p0 (point)))))

(defvar the-visibile-channel t)

(defun show-only-channel (n)
  "Show only channel n"
  (interactive "nShow only channel: ")
  (show-all-channels)
  (add-to-invisibility-spec 'SysEx)   (add-to-invisibility-spec 'Meta)
  (setq the-visible-channel n)
  (mapcar 
   (lambda (ch) 
     (if (not (= n ch))
       (add-to-invisibility-spec ch)))
   (number-interval 1 16)))

(defun show-all-channels ()
  (interactive)
  (setq buffer-invisibility-spec nil))

(defun next-visible-line ()
  (let* ((overlays (overlays-at (point))))
    (if (not (null overlays))
        (let ((overlay-props (overlay-get (car overlays) 'invisible)))
          (next-line 1)
          (if (not (eq overlay-props the-visible-channel))
              (next-visible-line)))
        (next-line 1))))


; ---------------------------------------------------------------------------------------------------------------
; Midi playing

(defvar midi-player-exc "c:/program files/Winamp/winamp.exe")

(defun play-midi-file (midi-file-path)
  (interactive "f:Play MIDI file: ")
  (start-process "MIDI play" nil midi-player-exc midi-file-path))

(defun play-midi-file-from-dired ()
  (interactive)
  (let ((selected-files (dired-get-marked-files nil)))
    (if (and (= 1 (length selected-files)) (file-regular-p (car selected-files)))
      (let* ((full-path-midi-file (car selected-files)))
         (play-midi-file full-path-midi-file))
      (progn
        (beep)
        (message "Cannot play. You should only select a single midi file.")))))

(defvar path-to-midi-error-file (concat laml-dir "styles/xml-in-laml/midi/" "midi/error.mid")
        "A path to a midi error file, which is played if no mirror file can be generated")  

; (defun process-laml-file-and-play ()
;   (interactive)
;   (let* ((laml-file-name (current-file))
;          (proper-laml-file-name-1 (file-name-proper laml-file-name))   ; with possible double name (icon name: x.icon)
;          (proper-laml-file-name-2 (file-name-proper (file-name-proper laml-file-name)))   ; without possible double name
;          (midi-file-name-1 (concat proper-laml-file-name-1 ".mid"))
;          (midi-file-name-2 (concat proper-laml-file-name-2 ".mid"))
;          (midi-file-path-1 (concat (current-directory) "midi-temp/" midi-file-name-1))
;          (midi-file-path-2 (concat (current-directory) "midi-temp/" midi-file-name-2)))        
;     (copy-file path-to-midi-error-file midi-file-path-1 t) 
;     (copy-file path-to-midi-error-file midi-file-path-2 t) 
;     (laml-sync-process-current-buffer)  
;     (message "A MIDI file has been generated in midi-temp. Now playing...")
;     (cond ((file-exists-p midi-file-path-1)   ; with double name
;            (play-midi-file midi-file-path-1))
;           ((file-exists-p midi-file-path-2)   ; without double name
;            (play-midi-file midi-file-path-2))
;           (t (error "Process-laml-file-and-play: Should not happen:")))))

(defun process-laml-file-and-play ()
  (interactive)
  (let* ((laml-file-name (current-file))
         (proper-laml-file-name (file-name-proper laml-file-name))   ; with possible double name (icon name: x.icon)
         (midi-file-name (concat proper-laml-file-name ".mid"))
         (midi-file-path (concat (current-directory) "midi-temp/" midi-file-name))
        )
    (copy-file path-to-midi-error-file midi-file-path t) 
    (laml-sync-process-current-buffer)  
    (message "A MIDI file has been generated in midi-temp. Now playing...")
    (cond ((file-exists-p midi-file-path)   ; with possible double name
            (play-midi-file midi-file-path))
          (t (error "Process-laml-file-and-play: Should not happen:")))))


(defun process-laml-file-and-save (target-file-name)
  (interactive "sName of target midi file (without extension): ")
  (let* ((kind (kind-of-midl-file-in-current-buffer)))
    (cond ((eq 'midi kind)      (process-laml-midi-file-and-save target-file-name))
          ((eq 'multi-pad kind) (process-laml-multi-pad-file-and-save target-file-name))
          (t (error (concat "process-laml-file-and-save: Unknown kind of midl file" (symbol-to-string kind)))))))

(defvar default-icon-name "S910")

(defun process-laml-midi-file-and-save (target-file-name)
  (let* ((laml-file-name (current-file))
         (proper-laml-file-name (file-name-proper laml-file-name))   
         (temp-source-file-path (concat (current-directory) "midi-temp/" proper-laml-file-name "." "mid"))
         (target-file-path (concat (current-directory) target-file-name "." "mid")))
    (laml-sync-process-current-buffer)
    (copy-file temp-source-file-path target-file-path t)
    (message (concat "The file "  target-file-path  " has been created."))
))

(defun process-laml-multi-pad-file-and-save (target-file-name)
  (let* ((laml-file-name (current-file))
         (proper-laml-file-name (file-name-proper laml-file-name))
         (icon-name (file-name-extension proper-laml-file-name))  ; because laml-file-name has double extension - icon in the middle.
         (temp-source-file-path (concat (current-directory) "midi-temp/" proper-laml-file-name "." "mid"))
         (target-file-path 
             (if icon-name
                 (concat (current-directory) target-file-name "." icon-name "." "pad")
                 (concat (current-directory) target-file-name "." default-icon-name "." "pad"))))
    (laml-sync-process-current-buffer)
    (copy-file temp-source-file-path target-file-path t)
    (message (concat "The file "  target-file-path  " has been created."))))



; ---------------------------------------------------------------------------------------------------
; Midl source stack

(defvar midl-source-file-stack '())
(setq midl-source-file-stack '())

(defun pop-and-reestablish-midl-file ()
  (interactive)
  (if (not (null midl-source-file-stack))
      (let ((file-path (car midl-source-file-stack)))
        (erase-buffer)
        (insert-file file-path)
        (delete-file file-path)
        (setq midl-source-file-stack (cdr midl-source-file-stack))
        (message (message (concat "The source file has been reestablished from the stack. Remaining entries on the stack: " 
                                   (int-to-string (length midl-source-file-stack))))))
      (error (concat "The midl source file stack is empty. Nothing done"))))

(defun push-current-midl-buffer (buf)
 (save-excursion
  (set-buffer buf)
  (let ((temp-midl-file (concat (current-directory) "midi-temp/" (int-to-string (length midl-source-file-stack)) "." "midl")))
    (write-region (point-min) (point-max) temp-midl-file nil 0)
    (setq midl-source-file-stack (cons temp-midl-file midl-source-file-stack)))))

; ---------------------------------------------------------------------------------------------------

(defun process-laml-file-save-and-push ()
  (interactive)
  (let* ((kind (kind-of-midl-file-in-current-buffer)))
    (cond ((eq 'midi kind)      (process-laml-midi-file-save-and-push))
          ((eq 'multi-pad kind) (process-laml-multi-pad-file-save-and-push))
          (t (error (concat "process-laml-file-save-and-push: Unknown kind of midl file" (symbol-to-string kind)))))))

(defun process-laml-midi-file-save-and-push ()
  (let* ((cur-buf (current-buffer))
         (laml-file-name (current-file))
         (proper-laml-file-name (file-name-proper laml-file-name))
         (temp-midi-source-path (concat (current-directory) "midi-temp/" proper-laml-file-name "." "mid"))
         (temp-laml-target-path (concat (current-directory) "midi-temp/" "temp" "." "laml"))
         (processing-mode (find-processing-mode-of-current-buffer))
         (counter-transposition (find-counter-transposition-of-current-buffer))
        )
    (message "Generating MIDI file from LAML file...")
    (laml-sync-process-current-buffer)   ; makes mid og pad file in midi-temp directory.
    (push-current-midl-buffer cur-buf)
    (message "Reprocessing  MIDI file in order to produce a fresh LAML (midl) file...")
    (sync-midi-file-to-laml-file processing-mode counter-transposition nil temp-midi-source-path temp-laml-target-path)
    (set-buffer cur-buf)
    (erase-buffer)
    (insert-file temp-laml-target-path)
    (delete-file temp-laml-target-path)
    
    (message (concat "The source file has been substituted. The earlier source is pushed on the midl stack. "
                     "Use M-x pop-and-reestablish-midl-file to return to previous source file"))
))

(defun process-laml-multi-pad-file-save-and-push ()
  (let* ((cur-buf (current-buffer))
         (laml-file-name (current-file))
         (proper-laml-file-name (file-name-proper laml-file-name))
         (temp-midi-source-path-0 (concat (current-directory) "midi-temp/" proper-laml-file-name "." "mid"))
         (temp-midi-source-path (concat (current-directory) "midi-temp/" proper-laml-file-name "." "pad"))
         (temp-laml-target-path (concat (current-directory) "midi-temp/" "temp" "." "laml"))
         (processing-mode (find-processing-mode-of-current-buffer))
         (counter-transposition (find-counter-transposition-of-current-buffer))
        )
    (copy-file (concat laml-dir "styles/xml-in-laml/midi/" "templates/error-pad.tpl") temp-laml-target-path)  ; rewritten if everything is OK.
    (message "Generating MIDI multi-pad file from LAML file...")
    (laml-sync-process-current-buffer) ; gives -.mid file
    (rename-file temp-midi-source-path-0 temp-midi-source-path t)   ; now pad name. Important for subsequent midi-to-laml processing.
    (push-current-midl-buffer cur-buf)
    (message "Reprocessing  PAD file in order to produce a fresh LAML (midl) file...")
    (sync-midi-file-to-laml-file processing-mode counter-transposition nil temp-midi-source-path temp-laml-target-path)
    (set-buffer cur-buf)
    (erase-buffer)
    (insert-file temp-laml-target-path)
    (delete-file temp-laml-target-path)
    
    (message (concat "The source file has been substituted. The earlier source is pushed on the midl stack. "
                     "Use M-x pop-and-reestablish-midl-file to return to previous source file"))
))



; By looking at the midl midi laml source in the current buffer, determine its kind
; Return a symbol such as midi or multi-pad. Return nil for unknown type.
(defun kind-of-midl-file-in-current-buffer ()
 (save-excursion
   (goto-char (point-max))
   (backward-sexp 1)
   (cond ((looking-at "(StandardMidiFile") 'midi)
         ((looking-at "(TyrosMultiPad") 'multi-pad)
         (else nil))))
              
  

; ---------------------------------------------------------------------------------------------------------------
; Score drawing

(defvar score-counter-transpostion 0)

; Decorate midi messages with sores between the points p and m.
; When calle interactively, p and m is point and mark.
(defun add-score-comments-of-region (p m)
 "Decorate the selected region with score comments"
 (interactive "r")
 (display-message-or-buffer "Adding scores to all channels of the selected region...")
 (save-excursion
   (let* ((p0 (min p m))
          (pn (max p m)))
     (setq score-counter-transpostion (string-to-int (find-counter-transposition-of-current-buffer)))
     (goto-char pn) (beginning-of-line 1)
     (re-search-backward note-on-reg-exp p0 t) (beginning-of-line 1)
     (while (and (> (point) 1) (>= (point) p0))
       (message (concat "Progress: " (progress pn p0 (point))))
       (decorate-midi-message-line-with-score t) (beginning-of-line 1)
       (let ((back-search (re-search-backward note-on-reg-exp p0 t)))
         (if back-search
             (beginning-of-line 1)
             (goto-char (- p0 1)))))))
 (message "Scores added to region."))

(setq note-on-reg-exp (regular-expression '(concat "(" (zero-or-more " ") "NoteOn")))

; Decorate midi messages with sores between the points p and m.
; When calle interactively, p and m is point and mark.
; If channel is t, add scores for all channels. Else only for a specific channel.
(defun add-score-comments-of-region-channel (channel p m)
 "Decorate the selected region, and the given channel with score comments"
 (save-excursion
   (let* ((p0 (min p m))
          (pn (max p m)))
     (setq score-counter-transpostion (string-to-int (find-counter-transposition-of-current-buffer)))
     (goto-char pn) (beginning-of-line 1)
     (re-search-backward note-on-reg-exp p0 t) (beginning-of-line 1)
     (while (and (> (point) 1) (>= (point) p0))
       (message (concat "Progress: " (progress pn p0 (point))))
       (decorate-midi-message-line-with-score channel) (beginning-of-line 1)
       (let ((back-search (re-search-backward note-on-reg-exp p0 t)))
         (if back-search
             (beginning-of-line 1)
             (goto-char (- p0 1))))))))

(defun add-score-comments-of-form ()
  "Decorate the selected form with score comments. You are supposed to select a form by placing point at the initial parenthesis."
  (interactive)
  (message "Adding scores to all channels in form...")
  (save-excursion
    (let ((p0 (point)))
      (forward-sexp 1)
      (let ((pn (point)))
        (add-score-comments-of-region p0 pn))))
  (message "Scores added to form"))

(defun add-score-comments-of-form-channel (ch)
  "Decorate the selected form with score comments. You are supposed to select a form by placing point at the initial parenthesis."
  (interactive "nAdd score to which channel in form: ")
  (message "Adding scores to channel " (number-to-string ch) " in form...")
  (save-excursion
    (let ((p0 (point)))
      (forward-sexp 1)
      (let ((pn (point)))
        (add-score-comments-of-region-channel ch p0 pn))))
  (message "Scores added to form"))

(defun remove-score-comments-of-region (p m)
 "Remove the score comments of the selected region"
 (interactive "r")
 (save-excursion
   (let* ((p0 (min p m))
          (pn (max p m)))
     (goto-char pn)
     (while (> (point) p0)
       (message (concat "Progress: " (progress pn p0 (point))))
       (let ((search-res (re-search-backward score-comment-line-reg-exp p0 t)))
          (if search-res 
              (kill-line-not-cr)
              (goto-char p0))))))) 

(defun kill-line-not-cr ()
  (while (not (looking-at-chars (point) '(10 13))) (delete-char 1)))

(setq score-comment-line-reg-exp   (regular-expression '(or "; " "; o" "; <" )))

(defun remove-score-comments-of-form ()
  "Remove the score comments from form. You are supposed to select a form by placing point at the initial parenthesis."
  (interactive)
  (save-excursion
    (let ((p0 (point)))
      (forward-sexp 1)
      (let ((pn (point)))
        (remove-score-comments-of-region p0 pn))))
  (message "Removed"))

; OLD version
; (defun decorate-midi-message-line-with-score (channel)
;   (let ((channel-of-mes (channel-of-message-on-current-line)))
;      (if (or (eq channel t) (and channel-of-mes (= channel channel-of-mes)))
;          (let* ((kind-of-mes (kind-of-message-on-current-line)))
;            (if (and kind-of-mes (equal kind-of-mes "NoteOn"))
;                (let ((note-number (note-number-on-current-line)))
;                  (insert-comment-at-column-number score-start-column (draw-score-line note-number))))))))

; Decorate NoteOn message current line with score comment.
; Assume as a precondition that there is a NoteOn message on the current line.
; Assume also that point is at the beginning of the line.             
; Channel can be a number, or t for all channels.
(defun decorate-midi-message-line-with-score (channel)
  (let ((channel-of-mes (channel-of-message-on-current-line)))
     (if (or (eq channel t) (and channel-of-mes (= channel channel-of-mes)))
         (let ((note-number (note-number-on-current-line)))
           (insert-comment-at-column-number score-start-column (draw-score-line note-number))))))

(defvar lower-c-note-number nil)
(setq lower-c-note-number 60)    ; c4 = 60

(defun set-c-value (c-value)
 (interactive)
  (let ((before lower-c-note-number))
    (setq lower-c-note-number c-value)
    (message (concat "Lower C value changed from " (int-to-string before) " to " (int-to-string c-value)))))

(defun report-lower-c ()
  (interactive)
  (message (concat "Lower C in score comment has value " (int-to-string lower-c-note-number))))

(defvar score-start-column  125)
(setq score-start-column  125)

; Return a score line for note-number.
(defun draw-score-line (note-number)
  (let ((ct-note-number (+ score-counter-transpostion note-number)))   ; counter-transposed node number
    (concat
      (draw-dot       (+ lower-c-note-number -10) ct-note-number  'min) ; d, d#
      (draw-between-1 (+ lower-c-note-number -8) ct-note-number)   ; e    
      (draw-dot       (+ lower-c-note-number -7) ct-note-number)   ; f, f#
      (draw-between   (+ lower-c-note-number -5) ct-note-number)   ; g, g#    
      (draw-dot       (+ lower-c-note-number -3) ct-note-number)   ; a, a#
      (draw-between-1 (+ lower-c-note-number -1) ct-note-number)   ; h      

      (draw-line      (+ lower-c-note-number 0) ct-note-number)    ; c, c#
      (draw-between   (+ lower-c-note-number 2) ct-note-number)    ; d, d#
      (draw-line-1    (+ lower-c-note-number 4) ct-note-number)    ; e
      (draw-between   (+ lower-c-note-number 5) ct-note-number)    ; f, f#
      (draw-line      (+ lower-c-note-number 7) ct-note-number)    ; g, g#
      (draw-between   (+ lower-c-note-number 9) ct-note-number)    ; a, a#
      (draw-line-1    (+ lower-c-note-number 11) ct-note-number)   ; h
      (draw-between   (+ lower-c-note-number 12) ct-note-number)   ; c, c#
      (draw-line      (+ lower-c-note-number 14) ct-note-number)   ; d, d#
      (draw-between-1 (+ lower-c-note-number 16) ct-note-number)   ; e

      (draw-dot       (+ lower-c-note-number 17) ct-note-number)    ; f, f#
      (draw-between   (+ lower-c-note-number 19) ct-note-number)    ; g, g#
      (draw-dot       (+ lower-c-note-number 21) ct-note-number)    ; a, a#
      (draw-between-1 (+ lower-c-note-number 23) ct-note-number)   ; h
      (draw-dot       (+ lower-c-note-number 24) ct-note-number 'max) ; c, c#
    )))

(defun draw-line (low-value note-number &optional limit)
  (cond ((and (eq limit 'min) (< note-number low-value)) "<")
        ((= low-value note-number) "o")
        ((= (+ low-value 1) note-number) "=")
        ((and (eq limit 'max) (> note-number (+ low-value 1))) ">")
        (t "|")))

(defun draw-line-1 (low-value note-number &optional limit)
  (cond ((= low-value note-number) "o")
        ((and (eq limit 'max) (> note-number (+ low-value 1))) ">")
        (t "|")))

(defun draw-dot-1 (low-value note-number &optional limit)
  (cond ((= low-value note-number) "o")
        ((and (eq limit 'max) (> note-number low-value)) ">")
        (t ".")))

(defun draw-dot (low-value note-number &optional limit)
  (cond ((and (eq limit 'min) (< note-number low-value)) "<")
        ((= low-value note-number) "o")
        ((= (+ low-value 1) note-number) "=")
        ((and (eq limit 'max) (> note-number (+ low-value 1))) ">")
        (t ".")))

(defun draw-between (low-value note-number &optional limit)
  (cond ((= low-value note-number) "o")
        ((= (+ low-value 1) note-number) "=")
        ((and (eq limit 'max) (> note-number (+ low-value 1))) ">")
        (t " ")))

(defun draw-between-1 (low-value note-number &optional limit)
  (cond ((= low-value note-number) "o")
        ((and (eq limit 'max) (> note-number low-value)) ">")
        (t " ")))

; Return the column number of position p (such as (point))
(defun column-number-of (p)
  (save-excursion
    (beginning-of-line 1)
    (- p (point))))

; Insert comment-txt a column number cn at the current line
(defun insert-comment-at-column-number (cn txt)
  (delete-existing-comment-at-line)
  (end-of-line 1)
  (let ((eol-pos (column-number-of (point))))
    (cond ((<= eol-pos cn)
              (insert (make-string (- cn eol-pos) 32))
              (insert "; ")
              (insert txt))
          (t  (insert "")))))

(defun delete-existing-comment-at-line ()
 (save-excursion
  (end-of-line)
  (while (is-inside-comment)
     (backward-delete-char-untabify 1))
  (backward-char 1)
  (while (looking-at-chars (point) '(32))
     (delete-char 1) (backward-char 1))))


; point in front of message form.
; Return the kind of midi message at the current line. A string or nil.
(defun kind-of-message-on-current-line ()
  (save-excursion
    (let ((p0 (point))
          (eol-p (progn (end-of-line 1) (point))))
      (goto-char p0)
      (if (eobp)
          nil
          (progn
            (while (and (not (eobp)) (not (looking-at-chars (point) '(40)))) (forward-char 1)) ; goto start paren
            (if (or (eobp) (> (point) eol-p))
                nil
              (progn
                (forward-char 1)
                (if (looking-at-chars (point) '(40)) ; another start paren.
                    nil
                  (prog-name-under-point)))))))))

; point in front of message form.
; Return the channel of message at the current line. A number or nil
(defun channel-of-message-on-current-line ()
  (save-excursion
    (let ((p0 (point))
          (eol-p (progn (end-of-line 1) (point))))
      (goto-char p0)
      (if (eobp)
          nil
          (let ((res (search-forward "'channel" eol-p t)))
            (if res
                (progn
                  (while (looking-at-chars (point) '(32 34))   ; space, quote
                     (forward-char 1))
                  (let ((channel-string (prog-name-under-point)))
                    (string-to-number channel-string)))
                nil))))))


; point in front of NoteOn message form.
(defun note-number-on-current-line ()
 (save-excursion
   (search-forward "'note" nil t)
   (while (not (looking-at-chars (point) '(34))) (forward-char 1))  ; goto "
   (forward-char 1)
   (let ((str (prog-name-under-point)))
     (string-to-number str))))

; ---------------------------------------------------------------------------------------------------------------
; Progress feedback.

; actual value goes from from-value to to-value. Display percentage done progress.
(defun progress (from-value to-value actual-value)
  (concat (number-to-string (truncate (* (/ (float (abs (- actual-value from-value))) (abs (- from-value to-value))) 100))) "%% done..."))

; ---------------------------------------------------------------------------------------------------------------

; Return a string. Defaults to "absTime"
(defun find-processing-mode-of-current-buffer()
  (save-excursion
    (goto-char (point-min))
    (let ((search-res (search-forward "'mode" nil t)))
      (if search-res
          (progn
            (search-forward "\"" nil t)
            (prog-name-under-point))
          "absTime"))))

; Return a string. Defautls to "0"
(defun find-counter-transposition-of-current-buffer()
  (save-excursion
    (goto-char (point-min))
    (let ((search-res (search-forward "'counterTransposition" nil t)))
      (if search-res
          (progn
            (search-forward "\"" nil t)
            (prog-name-under-point))
          "0"))))
